@@ -27,7 +27,7 @@ where
 
 fn main() {
     let args = argsparser::parse_args();
-    if args.help {
+    if args.help == true {
         util::print_help(args.help_exitc, args.name);
     }
     if args.version {
@@ -38,16 +38,13 @@ fn main() {
     match args.sub_cmd {
         argsparser::Subcommands::Byt => {
             let mut lexer = Lexer::new({
-                let mut my_file = fs::File::open(&match &args.outfile {
-                    Some(f) => f,
-                    None => unreachable!(),
-                }).unwrap();
+                let mut my_file = fs::File::open(&args.file).unwrap();
 
                 let mut buf = String::new();
                 my_file.read_to_string(&mut buf).unwrap();
                 buf
             });
-            let lexed = lexer.lex();
+            let lexed = lexer.clone().lex();
             if args.lex_out {
                 println!("{:#?}", &lexed);
             }
@@ -55,10 +52,10 @@ fn main() {
             let mut parser = Parser::from_lexer(&mut lexer);
             let parsed = parser.parse();
             if args.prs_out {
-                println!("{:#?}", &parsed);
+                println!("{:#?}", parsed.clone());
             }
 
-            let encoded = bytecode::to_bytecode(parsed);
+            let encoded = bytecode::to_bytecode(parsed.clone());
             {
                 let mut bytecode_src = fs::File::create(&match &args.outfile {
                     Some(f) => f.clone(),
@@ -71,7 +68,10 @@ fn main() {
         argsparser::Subcommands::Run => {
             // TODO: if specified accept args.outfile
             let mut lexer = Lexer::new({
-                let mut my_file = fs::File::open(&args.file).unwrap();
+                let mut my_file = match fs::File::open(&args.file) {
+                    Err(e) => error_print("error opening file", format!("{}: {}", e, &args.file)),
+                    Ok(f) => f,
+                };
 
                 let mut buf = String::new();
                 my_file.read_to_string(&mut buf).unwrap();
@@ -103,6 +103,11 @@ fn main() {
 
             // Run when runtime implemented
         },
+        argsparser::Subcommands::Help => {
+            util::print_help(args.help_exitc, args.name);
+        },
+        argsparser::Subcommands::Version => {
+            util::print_version(args.name);
+        },
     }
-    
 }
